﻿using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Input;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 리스트 컬렉션 뷰
        /// </summary>
        private ListCollectionView listCollectionView;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 프로그램 시작하기 - Main()

        /// <summary>
        /// 프로그램 시작하기
        /// </summary>
        [STAThread]
        public static void Main()
        {
            Application application = new Application();

            application.Run(new MainWindow());
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Instance
        //////////////////////////////////////////////////////////////////////////////// Private
        ////////////////////////////////////////////////////////////////////// Event

        #region 필터 텍스트 박스 텍스트 변경시 처리하기 - filterTextBox_TextChanged(sender, e)

        /// <summary>
        /// 필터 텍스트 박스 텍스트 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void filterTextBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            if(this.listCollectionView == null)
            {
                return;
            }

            this.listCollectionView.Refresh();
        }

        #endregion
        #region Open 실행하기 - ExecuteOpen(sender, e)

        /// <summary>
        /// Open 실행하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void ExecuteOpen(object sender, ExecutedRoutedEventArgs e)
        {
            People people = People.Load(this);

            if(people != null)
            {
                this.listCollectionView = new ListCollectionView(people);

                this.listCollectionView.SortDescriptions.Add(new SortDescription("BirthDate", ListSortDirection.Ascending));

                this.filterTextBox.Text = string.Empty;

                this.listCollectionView.Filter = LastNameFilter;

                this.listBox.ItemsSource = this.listCollectionView;

                if(this.listBox.Items.Count > 0)
                {
                    this.listBox.SelectedIndex = 0;
                }
            }
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// Function

        #region 성 필터 처리하기 - LastNameFilter(value)

        /// <summary>
        /// 성 필터 처리하기
        /// </summary>
        /// <param name="value">값</param>
        /// <returns>처리 결과</returns>
        private bool LastNameFilter(object value)
        {
            return (value as Person).LastName.StartsWith(this.filterTextBox.Text, StringComparison.CurrentCultureIgnoreCase);
        }

        #endregion
    }
}